```{python setup}
#| include: false
import seedcase_sprout as sp
import subprocess
import seedir as sd
from pathlib import Path
from tempfile import TemporaryDirectory

temp_path = TemporaryDirectory()
package_path = Path(temp_path.name) / "diabetes-study"
subprocess.run(["uv", "init", str(package_path)])
package_path = sp.PackagePath(package_path)

def file_tree(package_path: Path) -> list[Path]:
    """Show the file tree for the data package, excluding `.git` files.

    Args:
        package_path: The path to the package directory.

    Returns:
        A string representation of the file tree.
    """
    # Check if the path is a directory and exists
    if not package_path.is_dir():
        raise ValueError(f"{package_path} is not a directory.")

    return sd.seedir(
        package_path,
        style="emoji",
        exclude_folders=[".git"],
        first="folders",
        printout=False
    )
```
